@@ -47,7 +47,8 @@ public:
   //bool SetModel(Lum::Base::Model* model);
 
   void Layout();
-  void Draw(int x, int y, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
   bool HandleKeyEvent(const Lum::OS::KeyEvent& event);
